@@ -6,7 +6,7 @@ import csv
 from .. import tools
 
 
-def fromShapefile(filename, start=None, end=None):
+def fromShapefile(filename, crs=None, start=None, end=None):
     """ Convert an ESRI file (.shp and .dbf must be present) to a
     ee.FeatureCollection
 
@@ -31,7 +31,8 @@ def fromShapefile(filename, start=None, end=None):
     types = dict(zip(field_names, field_types))
     features = []
 
-    projection = utils.getProjection(filename)
+    projection = utils.getProjection(filename) if not crs else crs
+    projection = str(projection)
 
     # filter records with start and end
     start = start if start else 0
@@ -120,6 +121,8 @@ def fromGeoJSON(filename=None, data=None, crs=None):
         if ty == 'GeometryCollection':
             ee_geom = utils.GEOMETRY_TYPES.get(ty)(geom, opt_proj=crs)
         else:
+            if ty == 'Polygon':
+                coords = utils.removeZ(coords) if utils.hasZ(coords) else coords
             ee_geom = utils.GEOMETRY_TYPES.get(ty)(coords, proj=ee.Projection(crs))
         ee_feat = ee.feature.Feature(ee_geom, properties)
         features.append(ee_feat)
